/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2020 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp20nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp20nid ;

DATA library.&dataset ;
INFILE datafile LRECL=1405;
INPUT
   ACCEPT  1-2              BUSCLAS  3-6             CANTPAY  7            
   CCULPSCO  8-9            CH2APP  10               CH8FINGD  11          
   CMSRVORD  12             COFI  13                 COMPLY  14            
   COMPLYPR  15             CRIMPURP  16             DETBFINE  17          
   DISPOSIT  18             EMPLOYNM  19             FCULPSCO  20-21       
   FRAUDTYP  22-23          FINSTDS  24              HISTORY  25           
   HSMISCND  26             INCORLOC  27             INCORPYR  28-31       
   INDICT  32               INPLEA1  33              INPLEA2  34           
   INPLEA3  35              INPLEA4  36              INPLEA5  37           
   INPLEA6  38              INPLEA7  39              INPLEA8  40           
   INPLEA9  41              INPLEA10  42             INPLEA11  43          
   INPLEA12  44             INNOPL1  45              INNOPL2  46           
   INNOPL3  47              INNOPL4  48              INNOPL5  49           
   INNOPL6  50              INNOPL7  51              INNOPL8  52           
   INNOPL9  53              INNOPL10  54             INNOPL11  55          
   INNOPL12  56             JANDC  57                NEWCNVTN  58          
   NOCOMP  59               NOCOUNTS  60-61          NOREAVAR  62          
   NOUSTAT  63              OBSTRUCT  64             OFFLVL  65-66         
   ORDERCE  67              ORGTYPE  68              OWNSTRCT  69          
   PLEA  70                 PRIMOFF  71-72           PRCIVIL  73           
   PRCRIME  74              PROBATN  75-76           PROBMON  77           
   PSR  78                  QUARTER  79              REAS1  80-83          
   REAS2  84-86             REAS3  87-88             REAS4  89-90          
   REAS5  91-93             REASON2  94              REASON3  95           
   REASON4  96              REASONS  97              REMEDORD  98          
   SELFREP  99              SENTRNGE  100            SOURCES  101          
   TOLERNCE  102            TYPEOTHS  103-104        VICTNOTE  105         
   VIOLATE  106             AMENDYR  107-110         SENTYR  111-114       
   BASEFINE  115-123        COSTASSM  124-127        DISGORGE  128         
   FINOFFST  129-135        FORFEITR  136-143        GLFINMAX  144-152     
   GLFINMIN  153-161        STATMIN  162             STATMAX  163-169      
   RESTCAT  170             FINECAT  171             SUSFNCAT  172         
   LCAT1  173               LCATHI  174              LCATS1  175           
   LCATSHI  176             LCATR1  177              LCATRHI  178          
   LCATC1  179              LCATCHI  180             LCATU1  181           
   LCATUHI  182             CPIDN  183-189           BUSTEXT $ 190         
   FINSTXT $ 191            OWNSTEXT $ 192           PRMONTXT $ 193-281    
   ORDERTXT $ 282-480       TYPEOTTX $ 481-596       MINFINML  597-600     
   MAXFINML  601-603        ADJOFL1  604-605         ADJOFLHI  606-607     
   ADJ_B1  608-609          ADJ_BHI  610-611         ADJ_C1  612-613       
   ADJ_CHI  614-615         ADJ_D1  616              ADJ_DHI  617          
   ADJ_E1  618              ADJ_EHI  619             ADJ_F1  620           
   ADJ_FHI  621             ADJ_G1  622              ADJ_GHI  623          
   ADJ_H1  624              ADJ_HHI  625             ADJ_I1  626           
   ADJ_IHI  627             ADJ_J1  628              ADJ_JHI  629          
   ADJ_K1  630              ADJ_KHI  631             ADJ_L1  632           
   ADJ_LHI  633             ADJ_M1  634              ADJ_MHI  635          
   ADJ_N1  636              ADJ_NHI  637             ADJ_O1  638           
   ADJ_OHI  639             ADJ_P1  640              ADJ_PHI  641          
   ADJ_Q1  642              ADJ_QHI  643             ADJ_R1  644           
   ADJ_RHI  645             ADJ_S1  646              ADJ_SHI  647          
   ADJ_T1  648              ADJ_THI  649             ADJ_U1  650           
   ADJ_UHI  651             BASADJ1  652             BASADJHI  653         
   BASE1  654-655           BASEHI  656-657          BASLN1  658           
   BASLNHI  659             ADJOFS1  660-661         ADJOFSHI  662-663     
   ADJS_B1  664-665         ADJS_BHI  666-667        ADJS_C1  668-669      
   ADJS_CHI  670-671        ADJS_D1  672             ADJS_DHI  673         
   ADJS_E1  674             ADJS_EHI  675            ADJS_F1  676          
   ADJS_FHI  677            ADJS_G1  678             ADJS_GHI  679         
   ADJS_H1  680             ADJS_HHI  681            ADJS_I1  682          
   ADJS_IHI  683            ADJS_J1  684             ADJS_JHI  685         
   ADJS_K1  686             ADJS_KHI  687            ADJS_L1  688          
   ADJS_LHI  689            ADJS_M1  690             ADJS_MHI  691         
   ADJS_N1  692             ADJS_NHI  693            ADJS_O1  694          
   ADJS_OHI  695            ADJS_P1  696             ADJS_PHI  697         
   ADJS_Q1  698             ADJS_QHI  699            ADJS_R1  700          
   ADJS_RHI  701            ADJS_S1  702             ADJS_SHI  703         
   ADJS_T1  704             ADJS_THI  705            ADJS_U1  706          
   ADJS_UHI  707            BASADS1  708             BASADSHI  709         
   BASES1  710-711          BASESHI  712-713         BASLNS1  714          
   BASLNSHI  715            ADJOFR1  716-717         ADJOFRHI  718-719     
   ADJR_B1  720-721         ADJR_BHI  722-723        ADJR_C1  724          
   ADJR_CHI  725            ADJR_D1  726             ADJR_DHI  727         
   ADJR_E1  728             ADJR_EHI  729            ADJR_F1  730          
   ADJR_FHI  731            ADJR_G1  732             ADJR_GHI  733         
   ADJR_H1  734             ADJR_HHI  735            ADJR_I1  736          
   ADJR_IHI  737            ADJR_J1  738             ADJR_JHI  739         
   ADJR_K1  740             ADJR_KHI  741            ADJR_L1  742          
   ADJR_LHI  743            ADJR_M1  744             ADJR_MHI  745         
   ADJR_N1  746             ADJR_NHI  747            ADJR_O1  748          
   ADJR_OHI  749            ADJR_P1  750             ADJR_PHI  751         
   ADJR_Q1  752             ADJR_QHI  753            ADJR_R1  754          
   ADJR_RHI  755            ADJR_S1  756             ADJR_SHI  757         
   ADJR_T1  758             ADJR_THI  759            ADJR_U1  760          
   ADJR_UHI  761            BASADR1  762             BASADRHI  763         
   BASER1  764-765          BASERHI  766-767         BASLNR1  768          
   BASLNRHI  769            ADJOFC1  770             ADJOFCHI  771         
   ADJC_B1  772             ADJC_BHI  773            ADJC_C1  774          
   ADJC_CHI  775            ADJC_D1  776             ADJC_DHI  777         
   ADJC_E1  778             ADJC_EHI  779            ADJC_F1  780          
   ADJC_FHI  781            ADJC_G1  782             ADJC_GHI  783         
   ADJC_H1  784             ADJC_HHI  785            ADJC_I1  786          
   ADJC_IHI  787            ADJC_J1  788             ADJC_JHI  789         
   ADJC_K1  790             ADJC_KHI  791            ADJC_L1  792          
   ADJC_LHI  793            ADJC_M1  794             ADJC_MHI  795         
   ADJC_N1  796             ADJC_NHI  797            ADJC_O1  798          
   ADJC_OHI  799            ADJC_P1  800             ADJC_PHI  801         
   ADJC_Q1  802             ADJC_QHI  803            ADJC_R1  804          
   ADJC_RHI  805            ADJC_S1  806             ADJC_SHI  807         
   ADJC_T1  808             ADJC_THI  809            ADJC_U1  810          
   ADJC_UHI  811            BASADC1  812             BASADCHI  813         
   BASEC1  814              BASECHI  815             BASLNC1  816          
   BASLNCHI  817            ADJOFU1  818             ADJOFUHI  819         
   ADJU_B1  820             ADJU_BHI  821            ADJU_C1  822          
   ADJU_CHI  823            ADJU_D1  824             ADJU_DHI  825         
   ADJU_E1  826             ADJU_EHI  827            ADJU_F1  828          
   ADJU_FHI  829            ADJU_G1  830             ADJU_GHI  831         
   ADJU_H1  832             ADJU_HHI  833            ADJU_I1  834          
   ADJU_IHI  835            ADJU_J1  836             ADJU_JHI  837         
   ADJU_K1  838             ADJU_KHI  839            ADJU_L1  840          
   ADJU_LHI  841            ADJU_M1  842             ADJU_MHI  843         
   ADJU_N1  844             ADJU_NHI  845            ADJU_O1  846          
   ADJU_OHI  847            ADJU_P1  848             ADJU_PHI  849         
   ADJU_Q1  850             ADJU_QHI  851            ADJU_R1  852          
   ADJU_RHI  853            ADJU_S1  854             ADJU_SHI  855         
   ADJU_T1  856             ADJU_THI  857            ADJU_U1  858          
   ADJU_UHI  859            BASADU1  860             BASADUHI  861         
   BASEU1  862              BASEUHI  863             BASLNU1  864          
   BASLNUHI  865            ADJL_B1 $ 866            ADJL_BHI $ 867        
   ADJL_C1 $ 868-869        ADJL_CHI $ 870-871       ADJL_D1 $ 872         
   ADJL_DHI $ 873           ADJL_E1 $ 874            ADJL_EHI $ 875        
   ADJL_F1 $ 876            ADJL_FHI $ 877           ADJL_G1 $ 878         
   ADJL_GHI $ 879           ADJL_H1 $ 880-881        ADJL_HHI $ 882-883    
   ADJL_I1 $ 884            ADJL_IHI $ 885           ADJL_J1 $ 886         
   ADJL_JHI $ 887           ADJL_K1 $ 888            ADJL_KHI $ 889        
   ADJL_L1 $ 890-891        ADJL_LHI $ 892-893       ADJL_M1 $ 894         
   ADJL_MHI $ 895           ADJL_N1 $ 896            ADJL_NHI $ 897        
   ADJL_O1 $ 898            ADJL_OHI $ 899           ADJL_P1 $ 900         
   ADJL_PHI $ 901           ADJL_Q1 $ 902            ADJL_QHI $ 903        
   ADJL_R1 $ 904            ADJL_RHI $ 905           ADJL_S1 $ 906         
   ADJL_SHI $ 907           ADJL_T1 $ 908            ADJL_THI $ 909        
   ADJL_U1 $ 910            ADJL_UHI $ 911           BASEL1 $ 912          
   BASELHI $ 913            ADSL_B1 $ 914            ADSL_BHI $ 915        
   ADSL_C1 $ 916-917        ADSL_CHI $ 918-919       ADSL_D1 $ 920         
   ADSL_DHI $ 921           ADSL_E1 $ 922            ADSL_EHI $ 923        
   ADSL_F1 $ 924            ADSL_FHI $ 925           ADSL_G1 $ 926         
   ADSL_GHI $ 927           ADSL_H1 $ 928-929        ADSL_HHI $ 930-931    
   ADSL_I1 $ 932            ADSL_IHI $ 933           ADSL_J1 $ 934         
   ADSL_JHI $ 935           ADSL_K1 $ 936            ADSL_KHI $ 937        
   ADSL_L1 $ 938-939        ADSL_LHI $ 940-941       ADSL_M1 $ 942         
   ADSL_MHI $ 943           ADSL_N1 $ 944            ADSL_NHI $ 945        
   ADSL_O1 $ 946            ADSL_OHI $ 947           ADSL_P1 $ 948         
   ADSL_PHI $ 949           ADSL_Q1 $ 950            ADSL_QHI $ 951        
   ADSL_R1 $ 952            ADSL_RHI $ 953           ADSL_S1 $ 954         
   ADSL_SHI $ 955           ADSL_T1 $ 956            ADSL_THI $ 957        
   ADSL_U1 $ 958            ADSL_UHI $ 959           BASESL1 $ 960         
   BASESLHI $ 961           ADRL_B1 $ 962            ADRL_BHI $ 963        
   ADRL_C1 $ 964            ADRL_CHI $ 965           ADRL_D1 $ 966         
   ADRL_DHI $ 967           ADRL_E1 $ 968            ADRL_EHI $ 969        
   ADRL_F1 $ 970            ADRL_FHI $ 971           ADRL_G1 $ 972         
   ADRL_GHI $ 973           ADRL_H1 $ 974            ADRL_HHI $ 975        
   ADRL_I1 $ 976            ADRL_IHI $ 977           ADRL_J1 $ 978         
   ADRL_JHI $ 979           ADRL_K1 $ 980            ADRL_KHI $ 981        
   ADRL_L1 $ 982            ADRL_LHI $ 983           ADRL_M1 $ 984         
   ADRL_MHI $ 985           ADRL_N1 $ 986            ADRL_NHI $ 987        
   ADRL_O1 $ 988            ADRL_OHI $ 989           ADRL_P1 $ 990         
   ADRL_PHI $ 991           ADRL_Q1 $ 992            ADRL_QHI $ 993        
   ADRL_R1 $ 994            ADRL_RHI $ 995           ADRL_S1 $ 996         
   ADRL_SHI $ 997           ADRL_T1 $ 998            ADRL_THI $ 999        
   ADRL_U1 $ 1000           ADRL_UHI $ 1001          BASERL1 $ 1002        
   BASERLHI $ 1003          ADCL_B1 $ 1004           ADCL_BHI $ 1005       
   ADCL_C1 $ 1006           ADCL_CHI $ 1007          ADCL_D1 $ 1008        
   ADCL_DHI $ 1009          ADCL_E1 $ 1010           ADCL_EHI $ 1011       
   ADCL_F1 $ 1012           ADCL_FHI $ 1013          ADCL_G1 $ 1014        
   ADCL_GHI $ 1015          ADCL_H1 $ 1016           ADCL_HHI $ 1017       
   ADCL_I1 $ 1018           ADCL_IHI $ 1019          ADCL_J1 $ 1020        
   ADCL_JHI $ 1021          ADCL_K1 $ 1022           ADCL_KHI $ 1023       
   ADCL_L1 $ 1024           ADCL_LHI $ 1025          ADCL_M1 $ 1026        
   ADCL_MHI $ 1027          ADCL_N1 $ 1028           ADCL_NHI $ 1029       
   ADCL_O1 $ 1030           ADCL_OHI $ 1031          ADCL_P1 $ 1032        
   ADCL_PHI $ 1033          ADCL_Q1 $ 1034           ADCL_QHI $ 1035       
   ADCL_R1 $ 1036           ADCL_RHI $ 1037          ADCL_S1 $ 1038        
   ADCL_SHI $ 1039          ADCL_T1 $ 1040           ADCL_THI $ 1041       
   ADCL_U1 $ 1042           ADCL_UHI $ 1043          BASECL1 $ 1044        
   BASECLHI $ 1045          ADUL_B1 $ 1046           ADUL_BHI $ 1047       
   ADUL_C1 $ 1048           ADUL_CHI $ 1049          ADUL_D1 $ 1050        
   ADUL_DHI $ 1051          ADUL_E1 $ 1052           ADUL_EHI $ 1053       
   ADUL_F1 $ 1054           ADUL_FHI $ 1055          ADUL_G1 $ 1056        
   ADUL_GHI $ 1057          ADUL_H1 $ 1058           ADUL_HHI $ 1059       
   ADUL_I1 $ 1060           ADUL_IHI $ 1061          ADUL_J1 $ 1062        
   ADUL_JHI $ 1063          ADUL_K1 $ 1064           ADUL_KHI $ 1065       
   ADUL_L1 $ 1066           ADUL_LHI $ 1067          ADUL_M1 $ 1068        
   ADUL_MHI $ 1069          ADUL_N1 $ 1070           ADUL_NHI $ 1071       
   ADUL_O1 $ 1072           ADUL_OHI $ 1073          ADUL_P1 $ 1074        
   ADUL_PHI $ 1075          ADUL_Q1 $ 1076           ADUL_QHI $ 1077       
   ADUL_R1 $ 1078           ADUL_RHI $ 1079          ADUL_S1 $ 1080        
   ADUL_SHI $ 1081          ADUL_T1 $ 1082           ADUL_THI $ 1083       
   ADUL_U1 $ 1084           ADUL_UHI $ 1085          BASEUL1 $ 1086        
   BASEULHI $ 1087          GDLINE1 $ 1088-1092      GDSTAT1 $ 1093-1097   
   GDREF1 $ 1098-1102       GDCROS1 $ 1103           GDUNDR1 $ 1104        
   GDLINEHI $ 1105-1109     GDSTATHI $ 1110-1114     GDREFHI $ 1115-1119   
   GDCROSHI $ 1120          GDUNDRHI $ 1121          STA1_1 $ 1122-1132    
   STA1_2 $ 1133-1140       STA1_3 $ 1141-1147       STA1_4 $ 1148-1153    
   STA1_5 $ 1154-1159       STA1_6 $ 1160-1165       STA1_7 $ 1166-1171    
   STA1_8 $ 1172-1177       STA1_9 $ 1178-1183       STA1_10 $ 1184-1190   
   STA1_11 $ 1191-1196      STA2_1 $ 1197-1206       STA2_2 $ 1207-1215    
   STA2_3 $ 1216-1221       STA2_4 $ 1222-1227       STA2_5 $ 1228         
   STA2_6 $ 1229            STA2_7 $ 1230            STA2_8 $ 1231         
   STA2_9 $ 1232            STA2_10 $ 1233           STA2_11 $ 1234        
   STA3_1 $ 1235-1245       STA3_2 $ 1246-1248       STA3_3 $ 1249         
   STA3_4 $ 1250            STA3_5 $ 1251            STA3_6 $ 1252         
   STA3_7 $ 1253            STA3_8 $ 1254            STA3_9 $ 1255         
   STA3_10 $ 1256           STA3_11 $ 1257           NWSTAT1 $ 1258-1268   
   NWSTAT2 $ 1269-1278      NWSTAT3 $ 1279-1289      NWSTAT4 $ 1290-1292   
   SMAX1  1293-1298         SMAX2  1299-1304         SMAX3  1305-1310      
   SMAX4  1311-1316         SMAX5  1317-1322         SMAX6  1323-1328      
   SMAX7  1329-1334         SMAX8  1335-1340         SMAX9  1341-1346      
   SMAX10  1347-1352        SMAX11  1353-1358        SMIN1  1359           
   SMIN2  1360              SMIN3  1361              SMIN4  1362           
   SMIN5  1363              SMIN6  1364              SMIN7  1365           
   SMIN8  1366              SMIN9  1367              SMIN10  1368          
   SMIN11  1369             RETEXT1 $ 1370-1401      RETEXT2 $ 1402        
   RETEXT3 $ 1403           RETEXT4 $ 1404           RETEXT5 $ 1405        
 ;                       

LENGTH
   ACCEPT 3                 BUSCLAS 4                CANTPAY 3             
   CCULPSCO 3               CH2APP 3                 CH8FINGD 3            
   CMSRVORD 3               COFI 3                   COMPLY 3              
   COMPLYPR 3               CRIMPURP 3               DETBFINE 3            
   DISPOSIT 3               EMPLOYNM 3               FCULPSCO 3            
   FRAUDTYP 3               FINSTDS 3                HISTORY 3             
   HSMISCND 3               INCORLOC 3               INCORPYR 4            
   INDICT 3                 INPLEA1 3                INPLEA2 3             
   INPLEA3 3                INPLEA4 3                INPLEA5 3             
   INPLEA6 3                INPLEA7 3                INPLEA8 3             
   INPLEA9 3                INPLEA10 3               INPLEA11 3            
   INPLEA12 3               INNOPL1 3                INNOPL2 3             
   INNOPL3 3                INNOPL4 3                INNOPL5 3             
   INNOPL6 3                INNOPL7 3                INNOPL8 3             
   INNOPL9 3                INNOPL10 3               INNOPL11 3            
   INNOPL12 3               JANDC 3                  NEWCNVTN 3            
   NOCOMP 3                 NOCOUNTS 3               NOREAVAR 3            
   NOUSTAT 3                OBSTRUCT 3               OFFLVL 3              
   ORDERCE 3                ORGTYPE 3                OWNSTRCT 3            
   PLEA 3                   PRIMOFF 3                PRCIVIL 3             
   PRCRIME 3                PROBATN 3                PROBMON 3             
   PSR 3                    QUARTER 3                REAS1 4               
   REAS2 4                  REAS3 3                  REAS4 3               
   REAS5 4                  REASON2 3                REASON3 3             
   REASON4 3                REASONS 3                REMEDORD 3            
   SELFREP 3                SENTRNGE 3               SOURCES 3             
   TOLERNCE 3               TYPEOTHS 3               VICTNOTE 3            
   VIOLATE 3                AMENDYR 4                SENTYR 4              
   BASEFINE 6               COSTASSM 4               DISGORGE 3            
   FINOFFST 6               FORFEITR 6               GLFINMAX 6            
   GLFINMIN 6               STATMIN 3                STATMAX 6             
   RESTCAT 3                FINECAT 3                SUSFNCAT 3            
   LCAT1 3                  LCATHI 3                 LCATS1 3              
   LCATSHI 3                LCATR1 3                 LCATRHI 3             
   LCATC1 3                 LCATCHI 3                LCATU1 3              
   LCATUHI 3                CPIDN 6                  ADJOFL1 3             
   ADJOFLHI 3               ADJ_B1 3                 ADJ_BHI 3             
   ADJ_C1 3                 ADJ_CHI 3                ADJ_D1 3              
   ADJ_DHI 3                ADJ_E1 3                 ADJ_EHI 3             
   ADJ_F1 3                 ADJ_FHI 3                ADJ_G1 3              
   ADJ_GHI 3                ADJ_H1 3                 ADJ_HHI 3             
   ADJ_I1 3                 ADJ_IHI 3                ADJ_J1 3              
   ADJ_JHI 3                ADJ_K1 3                 ADJ_KHI 3             
   ADJ_L1 3                 ADJ_LHI 3                ADJ_M1 3              
   ADJ_MHI 3                ADJ_N1 3                 ADJ_NHI 3             
   ADJ_O1 3                 ADJ_OHI 3                ADJ_P1 3              
   ADJ_PHI 3                ADJ_Q1 3                 ADJ_QHI 3             
   ADJ_R1 3                 ADJ_RHI 3                ADJ_S1 3              
   ADJ_SHI 3                ADJ_T1 3                 ADJ_THI 3             
   ADJ_U1 3                 ADJ_UHI 3                BASADJ1 3             
   BASADJHI 3               BASE1 3                  BASEHI 3              
   BASLN1 3                 BASLNHI 3                ADJOFS1 3             
   ADJOFSHI 3               ADJS_B1 3                ADJS_BHI 3            
   ADJS_C1 3                ADJS_CHI 3               ADJS_D1 3             
   ADJS_DHI 3               ADJS_E1 3                ADJS_EHI 3            
   ADJS_F1 3                ADJS_FHI 3               ADJS_G1 3             
   ADJS_GHI 3               ADJS_H1 3                ADJS_HHI 3            
   ADJS_I1 3                ADJS_IHI 3               ADJS_J1 3             
   ADJS_JHI 3               ADJS_K1 3                ADJS_KHI 3            
   ADJS_L1 3                ADJS_LHI 3               ADJS_M1 3             
   ADJS_MHI 3               ADJS_N1 3                ADJS_NHI 3            
   ADJS_O1 3                ADJS_OHI 3               ADJS_P1 3             
   ADJS_PHI 3               ADJS_Q1 3                ADJS_QHI 3            
   ADJS_R1 3                ADJS_RHI 3               ADJS_S1 3             
   ADJS_SHI 3               ADJS_T1 3                ADJS_THI 3            
   ADJS_U1 3                ADJS_UHI 3               BASADS1 3             
   BASADSHI 3               BASES1 3                 BASESHI 3             
   BASLNS1 3                BASLNSHI 3               ADJOFR1 3             
   ADJOFRHI 3               ADJR_B1 3                ADJR_BHI 3            
   ADJR_C1 3                ADJR_CHI 3               ADJR_D1 3             
   ADJR_DHI 3               ADJR_E1 3                ADJR_EHI 3            
   ADJR_F1 3                ADJR_FHI 3               ADJR_G1 3             
   ADJR_GHI 3               ADJR_H1 3                ADJR_HHI 3            
   ADJR_I1 3                ADJR_IHI 3               ADJR_J1 3             
   ADJR_JHI 3               ADJR_K1 3                ADJR_KHI 3            
   ADJR_L1 3                ADJR_LHI 3               ADJR_M1 3             
   ADJR_MHI 3               ADJR_N1 3                ADJR_NHI 3            
   ADJR_O1 3                ADJR_OHI 3               ADJR_P1 3             
   ADJR_PHI 3               ADJR_Q1 3                ADJR_QHI 3            
   ADJR_R1 3                ADJR_RHI 3               ADJR_S1 3             
   ADJR_SHI 3               ADJR_T1 3                ADJR_THI 3            
   ADJR_U1 3                ADJR_UHI 3               BASADR1 3             
   BASADRHI 3               BASER1 3                 BASERHI 3             
   BASLNR1 3                BASLNRHI 3               ADJOFC1 3             
   ADJOFCHI 3               ADJC_B1 3                ADJC_BHI 3            
   ADJC_C1 3                ADJC_CHI 3               ADJC_D1 3             
   ADJC_DHI 3               ADJC_E1 3                ADJC_EHI 3            
   ADJC_F1 3                ADJC_FHI 3               ADJC_G1 3             
   ADJC_GHI 3               ADJC_H1 3                ADJC_HHI 3            
   ADJC_I1 3                ADJC_IHI 3               ADJC_J1 3             
   ADJC_JHI 3               ADJC_K1 3                ADJC_KHI 3            
   ADJC_L1 3                ADJC_LHI 3               ADJC_M1 3             
   ADJC_MHI 3               ADJC_N1 3                ADJC_NHI 3            
   ADJC_O1 3                ADJC_OHI 3               ADJC_P1 3             
   ADJC_PHI 3               ADJC_Q1 3                ADJC_QHI 3            
   ADJC_R1 3                ADJC_RHI 3               ADJC_S1 3             
   ADJC_SHI 3               ADJC_T1 3                ADJC_THI 3            
   ADJC_U1 3                ADJC_UHI 3               BASADC1 3             
   BASADCHI 3               BASEC1 3                 BASECHI 3             
   BASLNC1 3                BASLNCHI 3               ADJOFU1 3             
   ADJOFUHI 3               ADJU_B1 3                ADJU_BHI 3            
   ADJU_C1 3                ADJU_CHI 3               ADJU_D1 3             
   ADJU_DHI 3               ADJU_E1 3                ADJU_EHI 3            
   ADJU_F1 3                ADJU_FHI 3               ADJU_G1 3             
   ADJU_GHI 3               ADJU_H1 3                ADJU_HHI 3            
   ADJU_I1 3                ADJU_IHI 3               ADJU_J1 3             
   ADJU_JHI 3               ADJU_K1 3                ADJU_KHI 3            
   ADJU_L1 3                ADJU_LHI 3               ADJU_M1 3             
   ADJU_MHI 3               ADJU_N1 3                ADJU_NHI 3            
   ADJU_O1 3                ADJU_OHI 3               ADJU_P1 3             
   ADJU_PHI 3               ADJU_Q1 3                ADJU_QHI 3            
   ADJU_R1 3                ADJU_RHI 3               ADJU_S1 3             
   ADJU_SHI 3               ADJU_T1 3                ADJU_THI 3            
   ADJU_U1 3                ADJU_UHI 3               BASADU1 3             
   BASADUHI 3               BASEU1 3                 BASEUHI 3             
   BASLNU1 3                BASLNUHI 3               SMAX1 6               
   SMAX2 6                  SMAX3 6                  SMAX4 6               
   SMAX5 6                  SMAX6 6                  SMAX7 6               
   SMAX8 6                  SMAX9 6                  SMAX10 6              
   SMAX11 6                 SMIN1 3                  SMIN2 3               
   SMIN3 3                  SMIN4 3                  SMIN5 3               
   SMIN6 3                  SMIN7 3                  SMIN8 3               
   SMIN9 3                  SMIN10 3                 SMIN11 3 ;

          

RUN ;
